@@ -215,9 +215,18 @@ class run_yaml:
                 return self.dfs, self.gdfs
             else:
                 self.resume_after = ""
-                print(
-                    "CONFIG WARNING - RESUME_AFTER is ignored since there's no valid data files available."
-                )
+                if hasattr(self, "log") and self.log:
+                    self.log.warning(
+                        "CONFIG WARNING - RESUME_AFTER is ignored since there's no valid data files available."
+                    )
+                elif HAS_LOGGER and logger:
+                    print(
+                        "CONFIG WARNING - RESUME_AFTER is ignored since there's no valid data files available."
+                    )
+                else:
+                    print(
+                        "CONFIG WARNING - RESUME_AFTER is ignored since there's no valid data files available."
+                    )
 
         # otherwise, create new data stores
         if "VARS" in s:
