@@ -1,6 +1,16 @@
+# Load environment variables from .env file automatically
+try:
+    from .env_config import ensure_env_loaded
+
+    ensure_env_loaded()
+except ImportError:
+    # Fallback if env_config is not available
+    pass
+
 import os
 import numpy as np
 import pandas as pd
+import logging
 
 # Optional import for geopandas
 try:
@@ -437,7 +447,7 @@ class data_tables:
                         uri=uri_path, local_path=cache_dir, file_name=local_file_name
                     )
             except Exception as e:
-                print("export table {} failed. {}".format(otbl, e))
+                logging.error("Export table %s failed: %s", otbl, e)
         # clean up cache data folder
         cache_keep = os.environ.get("TLPT_ADLS_CACHE_KEEP", "0")
         cache_dir = os.environ.get("TLPT_ADLS_CACHE_DIR", "C:/Temp/tlpytools/adls")
@@ -462,4 +472,4 @@ class data_tables:
                     os.makedirs(filedir)
                 dict_df[otbl].to_csv(filepath, index=False)
             except Exception as e:
-                print("export table {} failed. {}".format(otbl, e))
+                logging.error("Export table %s failed: %s", otbl, e)
