@@ -1,7 +1,17 @@
+# Load environment variables from .env file automatically
+try:
+    from .env_config import ensure_env_loaded
+
+    ensure_env_loaded()
+except ImportError:
+    # Fallback if env_config is not available
+    pass
+
 import os
 import warnings
 import pandas as pd
 import json
+import logging
 from datetime import datetime
 from pathlib import Path
 
@@ -42,18 +52,27 @@ except ImportError:
     HAS_DATA_TABLES = False
     data_tables = None
 
+# Import the unified logger
+from .log import UnifiedLogger
 
-class DataStore:
+
+class DataStore(UnifiedLogger):
     """Enhanced data store for managing datasets with metadata and versioning."""
 
-    def __init__(self, base_path=None, project_name="default"):
+    def __init__(
+        self, base_path=None, project_name="default", logger: logging.Logger = None
+    ):
         """
         Initialize DataStore.
 
         Args:
             base_path (str, optional): Base directory for data storage
             project_name (str): Name of the project
+            logger (logging.Logger, optional): Logger instance. If not provided, creates new logger.
         """
+        # Initialize unified logging first
+        super().__init__(logger=logger, name=f"DataStore_{project_name}")
+
         if base_path is None:
             base_path = os.path.join(os.getcwd(), "data_store")
 
@@ -81,6 +100,10 @@ class DataStore:
         # Suppress performance warning for pytables
         warnings.filterwarnings("ignore", category=pd.io.pytables.PerformanceWarning)
 
+        self.log.info(f"DataStore initialized for project: {project_name}")
+        self.log.info(f"Base path: {self.base_path}")
+        self.log.info(f"Project path: {self.project_path}")
+
     def save_data(self, data, name, metadata=None, format="parquet", compression=None):
         """
         Save data with metadata.
@@ -131,7 +154,7 @@ class DataStore:
             return True
 
         except Exception as e:
-            print(f"Error saving data {name}: {e}")
+            self.log.error("Error saving data %s: %s", name, e)
             return False
 
     def load_data(self, name):
@@ -166,7 +189,7 @@ class DataStore:
                 raise ValueError(f"Unsupported format: {metadata['format']}")
 
         except Exception as e:
-            print(f"Error loading data {name}: {e}")
+            self.log.error("Error loading data %s: %s", name, e)
             return None
 
     def dataset_exists(self, name):
@@ -218,7 +241,7 @@ class DataStore:
                 return json.load(f)
 
         except Exception as e:
-            print(f"Error loading metadata for {name}: {e}")
+            self.log.error("Error loading metadata for %s: %s", name, str(e))
             return None
 
     def delete_dataset(self, name):
@@ -250,7 +273,7 @@ class DataStore:
             return True
 
         except Exception as e:
-            print(f"Error deleting dataset {name}: {e}")
+            self.log.error("Error deleting dataset %s: %s", name, str(e))
             return False
 
     def list_versions(self, name):
@@ -275,7 +298,6 @@ class DataStore:
         # Placeholder for future versioning implementation
         pass
 
-    # Legacy methods for backwards compatibility
     def load_existing_data(self, spec: dict):
         # initialize objects
         vars_obj = {}
@@ -285,7 +307,7 @@ class DataStore:
             vars_store = shelve.open(self.vars_filename)
         else:
             # no files available, return nothing
-            print(f"DATA WARNING - data store files are not available.")
+            self.log.warning("DATA WARNING - data store files are not available.")
             return None, None, None
 
         # build metadata
@@ -299,14 +321,18 @@ class DataStore:
         ]
         if completed_step != current_step:
             # steps do not match, return nothing
-            print(
-                f"CONFIG WARNING - data file has step {completed_step} but config wants to resume from step {current_step}."
+            self.log.warning(
+                "CONFIG WARNING - data file has step %s but config wants to resume from step %s.",
+                completed_step,
+                current_step,
             )
             return None, None, None
         if saved_completed_steps != current_completed_steps:
             # steps do not match, return nothing
-            print(
-                f"CONFIG WARNING - data file has previous steps {saved_completed_steps} do not match config {current_completed_steps}."
+            self.log.warning(
+                "CONFIG WARNING - data file has previous steps %s do not match config %s.",
+                saved_completed_steps,
+                current_completed_steps,
             )
             return None, None, None
 
@@ -348,182 +374,15 @@ class DataStore:
         for stored_var_name, stored_var_value in spec["VARS"].items():
             if stored_var_name not in list(vars_obj.keys()):
                 # warn that new variable values will be inserted
-                print(
-                    f"CONFIG WARNING - Variables {stored_var_name} is new, so it will be added."
+                self.log.warning(
+                    "CONFIG WARNING - Variables %s is new, so it will be added.",
+                    stored_var_name,
                 )
                 vars_obj[stored_var_name] = stored_var_value
             if stored_var_value != vars_obj[stored_var_name]:
                 # warn if variable values has changed
-                print(
-                    f"CONFIG WARNING - Variables {stored_var_name} have changed, using saved value {vars_obj[stored_var_name]} instead of {stored_var_value}."
-                )
-
-        # close data stores
-        vars_store.close()
-
-        # since we have successful resume after data loaded, write mode is now disabled
-        self.data_store_write_mode = False
-
-        # return data
-        return vars_obj, dfs_obj, gdfs_obj
-
-    def save_all_data(self, vars_obj, dfs_obj, gdfs_obj, current_step: str, spec: dict):
-        # skip write if step matches resume after or write mode is False
-        if self.data_store_write_mode == False or current_step != spec["RESUME_AFTER"]:
-            return False
-
-        # build metadata
-        metadata_obj = {
-            "var_list": list(vars_obj.keys()),
-            "dfs_list": list(dfs_obj.keys()),
-            "gdf_list": list(gdfs_obj.keys()),
-            "spec": spec,
-            "completed_step": current_step,
-        }
-
-        # clean up old files
-        for file in [
-            self.vars_filename + ".bak",
-            self.vars_filename + ".dat",
-            self.vars_filename + ".dir",
-            self.dfs_filename_pattern,
-            self.gdfs_filename,
-        ]:
-            if os.path.exists(file):
-                os.remove(file)
-
-        # establish data stores
-        vars_store = shelve.open(self.vars_filename)
-
-        # assign data into data stores
-        vars_store["metadata"] = metadata_obj
-        for var_name in metadata_obj["var_list"]:
-            vars_store[var_name] = vars_obj[var_name]
-        for df_name in metadata_obj["dfs_list"]:
-            export_df_filename = self.dfs_filename_pattern.format(df_name=df_name)
-            if os.path.exists(export_df_filename):
-                os.remove(export_df_filename)
-            # fix data types
-            for var_name, inferred_type in (
-                (dfs_obj[df_name].apply(pd.api.types.infer_dtype, axis=0))
-                .to_dict()
-                .items()
-            ):
-                if "mixed" in inferred_type:
-                    data_type = "str"
-                elif inferred_type == "decimal":
-                    data_type = "float64"
-                elif inferred_type == "string":
-                    data_type = "str"
-                elif inferred_type == "integer":
-                    # use float for int in case there are na values
-                    data_type = "float64"
-                elif inferred_type == "floating":
-                    data_type = "float64"
-                elif inferred_type == "date":
-                    data_type = "datetime64"
-                else:
-                    data_type = "str"
-                dfs_obj[df_name][var_name] = dfs_obj[df_name][var_name].astype(
-                    data_type
-                )
-                # fix non string column names
-                if type(var_name) != str:
-                    dfs_obj[df_name][str(var_name)] = dfs_obj[df_name][var_name].copy()
-                    dfs_obj[df_name] = dfs_obj[df_name].drop(columns=[var_name])
-
-            # export to parquet
-            dfs_obj[df_name].to_parquet(export_df_filename, engine="pyarrow")
-        for gdf_name in metadata_obj["gdf_list"]:
-            gdfs_obj[gdf_name].to_file(
-                self.gdfs_filename, layer=gdf_name, driver="GPKG"
-            )
-
-        # close and save data stores
-        vars_store.close()
-
-        return True
-
-    def load_existing_data(self, spec: dict):
-        # initialize objects
-        vars_obj = {}
-        dfs_obj = {}
-        gdfs_obj = {}
-        if os.path.exists(self.vars_filename + ".dat"):
-            vars_store = shelve.open(self.vars_filename)
-        else:
-            # no files available, return nothing
-            print(f"DATA WARNING - data store files are not available.")
-            return None, None, None
-
-        # build metadata
-        metadata_obj = vars_store["metadata"]
-        saved_spec = metadata_obj["spec"]
-        current_step = spec["RESUME_AFTER"]
-        completed_step = metadata_obj["completed_step"]
-        saved_completed_steps = spec["STEPS"][: spec["STEPS"].index(completed_step) + 1]
-        current_completed_steps = saved_spec["STEPS"][
-            : saved_spec["STEPS"].index(completed_step) + 1
-        ]
-        if completed_step != current_step:
-            # steps do not match, return nothing
-            print(
-                f"CONFIG WARNING - data file has step {completed_step} but config wants to resume from step {current_step}."
-            )
-            return None, None, None
-        if saved_completed_steps != current_completed_steps:
-            # steps do not match, return nothing
-            print(
-                f"CONFIG WARNING - data file has previous steps {saved_completed_steps} do not match config {current_completed_steps}."
-            )
-            return None, None, None
-
-        # build data objects
-        for var_name in metadata_obj["var_list"]:
-            vars_obj[var_name] = vars_store[var_name]
-        for df_name in metadata_obj["dfs_list"]:
-            input_df_filename = self.dfs_filename_pattern.format(df_name=df_name)
-            dfs_obj[df_name] = pd.read_parquet(input_df_filename, engine="pyarrow")
-        for gdf_name in metadata_obj["gdf_list"]:
-            gdfs_obj[gdf_name] = gpd.read_file(
-                self.gdfs_filename, layer=gdf_name, driver="GPKG"
-            )
-        # check and read additional tables added to spec
-        missing_spatials = set(spec["FILES"]["SPATIALS"].keys()).difference(
-            set(metadata_obj["gdf_list"])
-        )
-        query_spec = spec.copy()
-        missing_tbls = set(spec["FILES"]["INPUTS"].keys()).difference(
-            set(metadata_obj["dfs_list"])
-        )
-        if len(missing_tbls) > 0:
-            query_spec["FILES"]["INPUTS"] = {
-                key: query_spec["FILES"]["INPUTS"][key] for key in list(missing_tbls)
-            }
-            missing_dfs = data_tables.read_tbl_data(s=query_spec)
-            for tbl_name in missing_dfs.keys():
-                dfs_obj[tbl_name] = missing_dfs[tbl_name].copy()
-        if len(missing_spatials) > 0:
-            query_spec["FILES"]["SPATIALS"] = {
-                key: query_spec["FILES"]["SPATIALS"][key]
-                for key in list(missing_spatials)
-            }
-            missing_gdfs = data_tables.read_spatial_data(s=query_spec)
-            for tbl_name in missing_gdfs.keys():
-                gdfs_obj[tbl_name] = missing_gdfs[tbl_name].copy()
-
-        # check and load vars object
-        for stored_var_name, stored_var_value in spec["VARS"].items():
-            if stored_var_name not in list(vars_obj.keys()):
-                # warn that new variable values will be inserted
-                print(
-                    f"CONFIG WARNING - Variables {stored_var_name} is new, so it will be added."
-                )
-                vars_obj[stored_var_name] = stored_var_value
-            if stored_var_value != vars_obj[stored_var_name]:
-                # warn if variable values has changed
-                print(
-                    f"CONFIG WARNING - Variables {stored_var_name} have changed, using saved value {vars_obj[stored_var_name]} instead of {stored_var_value}."
+                self.log.warning(
+                    "CONFIG WARNING - Variables %s have changed, using saved value %s instead of %s.",
                 )
 
         # close data stores
