@@ -1,3 +1,12 @@
+# Load environment variables from .env file automatically
+try:
+    from .env_config import ensure_env_loaded
+
+    ensure_env_loaded()
+except ImportError:
+    # Fallback if env_config is not available
+    pass
+
 import os
 import logging
 import platform
@@ -6,8 +15,6 @@ import time
 import contextlib
 import numpy as np
 import pandas as pd
-import sqlalchemy as sql
-import pyodbc
 
 
 def setup_logger(name, log_file=None, level=logging.INFO, console_output=True):
@@ -64,8 +71,6 @@ def setup_logger(name, log_file=None, level=logging.INFO, console_output=True):
     try:
         logger.info(f"numpy: {np.__version__}")
         logger.info(f"pandas: {pd.__version__}")
-        logger.info(f"sqlalchemy: {sql.__version__}")
-        logger.info(f"pyodbc: {pyodbc.version}")
     except Exception as e:
         logger.warning(f"Could not log version information: {e}")
 
@@ -132,13 +137,70 @@ def configure_pandas_logging():
     pd.set_option("mode.chained_assignment", None)
 
 
-class logger:
+class UnifiedLogger:
+    """Unified logger class that provides consistent logging across tlpytools."""
+
+    _initialized_loggers = set()  # Track which loggers have been initialized
+
+    def __init__(
+        self,
+        logger: logging.Logger = None,
+        name: str = None,
+        log_file: str = None,
+        level: int = logging.INFO,
+    ):
+        """
+        Initialize unified logger.
+
+        Args:
+            logger: Optional existing logger instance. If provided, uses this logger.
+            name: Logger name. If not provided and logger is None, uses the class name.
+            log_file: Log file path. If not provided, creates one based on the class name.
+            level: Logging level (default: INFO).
+        """
+        if logger is not None:
+            # Use provided logger
+            self.log = logger
+        else:
+            # Create new logger
+            if name is None:
+                name = type(self).__name__
+
+            if log_file is None:
+                log_file = f"{name}.log"
+
+            self.log = setup_logger(name, log_file, level)
+
+        # Log initialization info only once per logger
+        logger_id = self.log.name if hasattr(self.log, "name") else str(id(self.log))
+        if logger_id not in self._initialized_loggers:
+            self._log_initialization_info()
+            self._initialized_loggers.add(logger_id)
+
+    def _log_initialization_info(self):
+        """Log standard initialization information."""
+        self.log.info("=== Logging initialized ===")
+        self.log.info("Time: %s", datetime.datetime.now())
+        self.log.info("Working directory: %s", os.getcwd())
+        self.log.info("Platform: %s", platform.platform())
+
+        # Log version information
+        try:
+            self.log.info("numpy: %s", np.__version__)
+            self.log.info("pandas: %s", pd.__version__)
+        except Exception as e:
+            self.log.warning("Could not log version information: %s", str(e))
+
+
+class logger(UnifiedLogger):
     """Legacy logger class for backwards compatibility."""
 
     def __init__(self) -> None:
-        self.log = None
+        # Initialize with None logger so UnifiedLogger creates a new one
+        super().__init__(logger=None)
 
     def init_logger(self, logFile=None, computer="run"):
+        """Legacy method for backwards compatibility."""
         # if log file name is None, use source class name
         if logFile == None:
             filename = "{}.log".format(type(self).__name__)
@@ -147,40 +209,10 @@ class logger:
         # get computer name
         name = "{}_{}".format(computer, platform.node())
 
-        # try get log handler if it exists
-        self.log = logging.getLogger(name)
+        # Create new logger using the modern setup_logger function
+        self.log = setup_logger(name, logFile, logging.DEBUG)
 
-        # if not, add log handler
-        if len(self.log.handlers) == 0:
-            # create logger
-            self.log = logging.getLogger(name)
-            self.log.setLevel(logging.DEBUG)
-            # create formatter and add it to the handlers
-            formatter = logging.Formatter(
-                "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
-            )
-            # create file handler
-            fh = logging.FileHandler(logFile)
-            fh.setLevel(logging.DEBUG)
-            fh.setFormatter(formatter)
-            self.log.addHandler(fh)
-            # create console handler
-            ch = logging.StreamHandler()
-            # ch.setLevel(logging.ERROR)
-            ch.setLevel(logging.DEBUG)
-            ch.setFormatter(formatter)
-            self.log.addHandler(ch)
-
-        # log message
-        self.log.info("===Logging enabled===")
-        self.log.info("Time - {}".format(datetime.datetime.now()))
-        self.log.info("CWD - {d}".format(d=os.getcwd()))
-        # print versions
-        self.log.info("numpy " + np.__version__)
-        self.log.info("pandas " + pd.__version__)
-        self.log.info("sqlalchemy " + sql.__version__)
-        self.log.info("pyodbc " + pyodbc.version)
-        self.log.info("ipfn " + "1.4.0")
+        # Note: Don't call _log_initialization_info() again since setup_logger already logs initialization
 
 
 class analyzer:
