@@ -70,7 +70,7 @@ class TestOrcaIntegration(unittest.TestCase):
             "operational_mode": {
                 "type": "local_testing",
                 "cloud": {
-                    "adls_url": "https://tlebtsprd01dail06lk01.dfs.core.windows.net",
+                    "adls_url": f"https://{os.getenv('ORCA_ADLS_URL', 'yourstorageaccount.dfs.core.windows.net')}",
                     "adls_container": "raw",
                     "adls_folder": "orca_cloud_model_runs",
                 },
@@ -108,7 +108,7 @@ class TestOrcaIntegration(unittest.TestCase):
         Test 1: Local testing mode - initialize and run model from start to finish.
 
         This test simulates:
-        python orca/orchestrator.py --action run_models --databank db_test_local
+        python -m tlpytools.orca --action run_models --databank db_test_local
         """
         print("\n=== Test 1: Local Testing Full Run ===")
 
@@ -194,7 +194,7 @@ class TestOrcaIntegration(unittest.TestCase):
         Test 2: Cloud production mode - initialize databank and upload to ADLS.
 
         This test simulates:
-        python orca/orchestrator.py --action initialize_databank --databank db_test_integration_init --mode cloud_production
+        python -m tlpytools.orca --action initialize_databank --databank db_test_integration_init --mode cloud_production
         """
         print("\n=== Test 2: Cloud Production Initialization ===")
 
@@ -272,7 +272,7 @@ class TestOrcaIntegration(unittest.TestCase):
         Test 3: Cloud production mode - download existing databank and complete run.
 
         This test simulates:
-        python orca/orchestrator.py --action run_models --databank db_test_integration_init --mode cloud_production
+        python -m tlpytools.orca --action run_models --databank db_test_integration_init --mode cloud_production
 
         Note: This test assumes a cloud databank exists or creates a local one to simulate download.
         """
