@@ -38,9 +38,7 @@ class TestOrcaLogger(unittest.TestCase):
     def tearDown(self):
         """Clean up test fixtures."""
         shutil.rmtree(self.test_dir, ignore_errors=True)
-        # Reset the singleton instance
-        OrcaLogger._instance = None
-        OrcaLogger._initialized = False
+        # Note: OrcaLogger no longer uses singleton pattern, so no cleanup needed
 
     def test_logger_initialization(self):
         """Test logger can be initialized."""
@@ -49,18 +47,27 @@ class TestOrcaLogger(unittest.TestCase):
         self.assertEqual(logger.log_file_path, self.log_file)
         self.assertTrue(os.path.exists(self.log_file))
 
-    def test_logger_singleton(self):
-        """Test logger behaves as singleton."""
-        logger1 = OrcaLogger(self.log_file)
-        logger2 = OrcaLogger()
-        self.assertIs(logger1, logger2)
+    def test_logger_isolation(self):
+        """Test logger instances are properly isolated."""
+        log_file1 = os.path.join(self.test_dir, "test1.log")
+        log_file2 = os.path.join(self.test_dir, "test2.log")
+
+        logger1 = OrcaLogger(log_file1)
+        logger2 = OrcaLogger(log_file2)
+
+        # They should be different instances
+        self.assertIsNot(logger1, logger2)
+
+        # They should have different log file paths
+        self.assertNotEqual(logger1.log_file_path, logger2.log_file_path)
 
     def test_child_logger(self):
         """Test child logger creation."""
         logger = OrcaLogger(self.log_file)
         child = logger.get_child_logger("test_child")
         self.assertIsNotNone(child)
-        self.assertEqual(child.name, "orca_orchestrator.test_child")
+        # Check that the child logger name ends with .test_child
+        self.assertTrue(child.name.endswith(".test_child"))
 
 
 class TestOrcaState(unittest.TestCase):
@@ -346,9 +353,7 @@ class TestOrcaOrchestrator(unittest.TestCase):
     def tearDown(self):
         """Clean up test fixtures."""
         shutil.rmtree(self.test_dir, ignore_errors=True)
-        # Reset the singleton logger
-        OrcaLogger._instance = None
-        OrcaLogger._initialized = False
+        # Note: OrcaLogger no longer uses singleton pattern, so no cleanup needed
 
     def _create_test_orchestrator(self, mode="local_testing"):
         """Helper to create test orchestrator with config."""
